==> mimepp-1.0.tgz: include/mimepp/mimepp.h <==
//=============================================================================
// File:       mimepp.h
// Contents:   MIME++ library include file
// Maintainer: Doug Sauder <dwsauder@fwb.gulf.net>
// WWW:        http://www.fwb.gulf.net/~dwsauder/mimepp.html
// $Revision: 3.0 $
// $Date: 1997-07-26 15:34:52-05 $
//
// Copyright (c) 1996, 1997 Douglas W. Sauder
// All rights reserved.
// 
// IN NO EVENT SHALL DOUGLAS W. SAUDER BE LIABLE TO ANY PARTY FOR DIRECT,
// INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING OUT OF
// THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION, EVEN IF DOUGLAS W. SAUDER
// HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//
// DOUGLAS W. SAUDER SPECIFICALLY DISCLAIMS ANY WARRANTIES, INCLUDING, BUT
// NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
// PARTICULAR PURPOSE.  THE SOFTWARE PROVIDED HEREUNDER IS ON AN "AS IS"
// BASIS, AND DOUGLAS W. SAUDER HAS NO OBLIGATION TO PROVIDE MAINTENANCE,
// SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
//
//=============================================================================

#ifndef DW_MIMEPP_H
#define DW_MIMEPP_H

#ifndef DW_CONFIG_H
#include <mimepp/config.h>
#endif

#ifndef DW_ENUM_H
#include <mimepp/enum.h>
#endif

#ifndef DW_ADDRESS_H
#include <mimepp/address.h>
#endif

#ifndef DW_ADDRLIST_H
#include <mimepp/addrlist.h>
#endif

#ifndef DW_BODY_H
#include <mimepp/body.h>
#endif

#ifndef DW_BODYPART_H
#include <mimepp/bodypart.h>
#endif

#ifndef DW_BOYERMOR_H
#include <mimepp/boyermor.h>
#endif

#ifndef DW_DATETIME_H
#include <mimepp/datetime.h>
#endif

#ifndef DW_DISPTYPE_H
#include <mimepp/disptype.h>
#endif

#ifndef DW_DWSTRING_H
#include <mimepp/string.h>
#endif

#ifndef DW_ENTITY_H
#include <mimepp/entity.h>
#endif

#ifndef DW_FIELD_H
#include <mimepp/field.h>
#endif

#ifndef DW_FIELDBDY_H
#include <mimepp/fieldbdy.h>
#endif

#ifndef DW_GROUP_H
#include <mimepp/group.h>
#endif

#ifndef DW_HEADER_H
#include <mimepp/headers.h>
#endif

#ifndef DW_MAILBOX_H
#include <mimepp/mailbox.h>
#endif

#ifndef DW_MBOXLIST_H
#include <mimepp/mboxlist.h>
#endif

#ifndef DW_MECHANSM_H
#include <mimepp/mechansm.h>
#endif

#ifndef DW_MEDIATYP_H
#include <mimepp/mediatyp.h>
#endif

#ifndef DW_MESSAGE_H
#include <mimepp/message.h>
#endif

#ifndef DW_MSGCMP_H
#include <mimepp/msgcmp.h>
#endif

#ifndef DW_MSGID_H
#include <mimepp/msgid.h>
#endif

#ifndef DW_NNTP_H
#include <mimepp/nntp.h>
#endif

#ifndef DW_PARAM_H
#include <mimepp/param.h>
#endif

#ifndef DW_POP_H
#include <mimepp/pop.h>
#endif

#ifndef DW_PROTOCOL_H
#include <mimepp/protocol.h>
#endif

#ifndef DW_SMTP_H
#include <mimepp/smtp.h>
#endif

#ifndef DW_TEXT_H
#include <mimepp/text.h>
#endif

#ifndef DW_TOKEN_H
#include <mimepp/token.h>
#endif

#ifndef DW_UUENCODE_H
#include <mimepp/uuencode.h>
#endif

#ifndef DW_UTILITY_H
#include <mimepp/utility.h>
#endif

#endif

==> mimepp-1.3.3.tgz: include/mimepp/mimepp.h <==
//=============================================================================
// File:       mimepp.h
// Contents:   MIME++ library include file
// Maintainer: Doug Sauder <dwsauder@hunnysoft.com>
// WWW:        http://www.hunnysoft.com/mimepp/
//
// Copyright (c) 1996-2001 Hunny Software, Inc
// All rights reserved.
//
// IN NO EVENT SHALL HUNNY SOFTWARE, INC BE LIABLE TO ANY PARTY FOR DIRECT,
// INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING OUT OF
// THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION, EVEN IF HUNNY SOFTWARE,
// INC HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//
// HUNNY SOFTWARE, INC SPECIFICALLY DISCLAIMS ANY WARRANTIES, INCLUDING,
// BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
// FITNESS FOR A PARTICULAR PURPOSE.  THE SOFTWARE PROVIDED HEREUNDER IS ON
// AN "AS IS" BASIS, AND HUNNY SOFTWARE, INC HAS NO OBLIGATION TO PROVIDE
// MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
//
//=============================================================================

#ifndef DW_MIMEPP_H
#define DW_MIMEPP_H

#ifndef DW_CONFIG_H
#include <mimepp/config.h>
#endif

#ifndef DW_STRING_H
#include <mimepp/string.h>
#endif

#ifndef DW_SYSTEM_H
#include <mimepp/system.h>
#endif

#ifndef DW_ENUM_H
#include <mimepp/enum.h>
#endif

#ifndef DW_ADDRESS_H
#include <mimepp/address.h>
#endif

#ifndef DW_ADDRLIST_H
#include <mimepp/addrlist.h>
#endif

#ifndef DW_APPLFILE_H
#include <mimepp/applfile.h>
#endif

#ifndef DW_BODY_H
#include <mimepp/body.h>
#endif

#ifndef DW_BODYPART_H
#include <mimepp/bodypart.h>
#endif

#ifndef DW_BOYERMOR_H
#include <mimepp/boyermor.h>
#endif

#ifndef DW_DATETIME_H
#include <mimepp/datetime.h>
#endif

#ifndef DW_DISPTYPE_H
#include <mimepp/disptype.h>
#endif

#ifndef DW_DWSTRING_H
#include <mimepp/string.h>
#endif

#ifndef DW_ENTITY_H
#include <mimepp/entity.h>
#endif

#ifndef DW_FIELD_H
#include <mimepp/field.h>
#endif

#ifndef DW_FIELDBDY_H
#include <mimepp/fieldbdy.h>
#endif

#ifndef DW_GROUP_H
#include <mimepp/group.h>
#endif

#ifndef DW_HEADERS_H
#include <mimepp/headers.h>
#endif

#ifndef DW_MAILBOX_H
#include <mimepp/mailbox.h>
#endif

#ifndef DW_MBOXLIST_H
#include <mimepp/mboxlist.h>
#endif

#ifndef DW_MECHANSM_H
#include <mimepp/mechansm.h>
#endif

#ifndef DW_MEDIATYP_H
#include <mimepp/mediatyp.h>
#endif

#ifndef DW_MESSAGE_H
#include <mimepp/message.h>
#endif

#ifndef DW_MSGCMP_H
#include <mimepp/msgcmp.h>
#endif

#ifndef DW_MSGID_H
#include <mimepp/msgid.h>
#endif

#ifndef DW_NNTP_H
#include <mimepp/nntp.h>
#endif

#ifndef DW_PARAM_H
#include <mimepp/param.h>
#endif

#ifndef DW_POP_H
#include <mimepp/pop.h>
#endif

#ifndef DW_PROTOCOL_H
#include <mimepp/protocol.h>
#endif

#ifndef DW_STAMP_H
#include <mimepp/stamp.h>
#endif

#ifndef DW_SMTP_H
#include <mimepp/smtp.h>
#endif

#ifndef DW_TEXT_H
#include <mimepp/text.h>
#endif

#ifndef DW_TOKEN_H
#include <mimepp/token.h>
#endif

#ifndef DW_UUENCODE_H
#include <mimepp/uuencode.h>
#endif

#ifndef DW_UTILITY_H
#include <mimepp/utility.h>
#endif

#endif
